% table2nrbf.m

% Ron Alquist

% Bank of Canada

% January 2009


% This program returns the estimates of the non-regression based forecasts: the random walk, futures price,

% spread (without estimated parameters), and Hotelling (if applicable) forecasts in Table 2 of of Alquist and

% Kilian's "What Do We Learn From the Price of Crude Oil Futures?"


clear all;

format short g;

load prices.txt;

load irate.txt;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Variable names

date = prices(:,1:2);

s = prices(:,3);

f3m = prices(:,5);

sp3m = s.*(1 + log(f3m./s));

i3m = irate(:,3);

sfi3m = s.*(1 + i3m/100).^(0.25);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('3-month RW forecast');

rwmat = [date(4:end,:), s(4:end,1)-s(1:end-3,1)];

b = find(rwmat(:,1)==1991 & rwmat(:,2)==1);

e = find(rwmat(:,1)==2007 & rwmat(:,2)==2);

rwmat1 = rwmat(b:e,:);

rwmspe = mean(rwmat1(:,3).^2);

rwbias = mean(rwmat1(:,3));

rwmape = mean(abs(rwmat1(:,3)));

disp('MSPE:');

disp(rwmspe);

disp('Bias:');

disp(rwbias);

disp('MAPE:');

disp(rwmape);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('3-month futures forecast');

[mspe,msperat,mspepval,bias] = mspedm(s,f3m,3,1990,date);

[mape,maperat,mapepval] = mapedm(s,f3m,3,1990,date);

[sr,srpval] = nrbpt(s,f3m,3,1990,date);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('3-month spread (without estimated parameters)');

[mspe,msperat,mspepval,bias] = mspedm(s,sp3m,3,1990,date);

[mape,maperat,mapepval] = mapedm(s,sp3m,3,1990,date);

[sr,srpval] = nrbpt(s,sp3m,3,1990,date);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('3-month Hotelling forecast');

[mspe,msperat,mspepval,bias] = mspedm(s,sfi3m,3,1990,date);

[mape,maperat,mapepval] = mapedm(s,sfi3m,3,1990,date);

[sr,srpval] = nrbpt(s,sfi3m,3,1990,date);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);