% table4nrbf.m

% Ron Alquist

% January 2009


% This program returns the estimates of the non-regression based forecasts: the random walk, futures price,

% spread (without estimated parameters), Hotelling (if applicable), and Consensus Economics

% (if applicable) forecasts in Table 4 of of Alquist and Kilian's "What Do We Learn From the Price of

% Crude Oil Futures?"



clear all;

format short g;

load prices.txt;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Variable names

date = prices(:,1:2);

s = prices(:,3);

f9m = prices(:,7);

sp9m = s.*(1 + log(f9m./s));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('9-month RW forecast');

rwmat = [date(10:end,:), s(10:end,1)-s(1:end-9,1)];

b = find(rwmat(:,1)==1991 & rwmat(:,2)==1);

e = find(rwmat(:,1)==2007 & rwmat(:,2)==2);

rwmat1 = rwmat(b:e,:);

rwmspe = mean(rwmat1(:,3).^2);

rwbias = mean(rwmat1(:,3));

rwmape = mean(abs(rwmat1(:,3)));

disp('MSPE:');

disp(rwmspe);

disp('Bias:');

disp(rwbias);

disp('MAPE:');

disp(rwmape);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('9-month futures forecast');

[mspe,msperat,mspepval,bias] = mspedm(s,f9m,9,1990,date);

[mape,maperat,mapepval] = mapedm(s,f9m,9,1990,date);

[sr,srpval] = nrbpt(s,f9m,9,1990,date);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('9-month spread forecast (without estimated parameters)');

[mspe,msperat,mspepval,bias] = mspedm(s,sp9m,9,1990,date);

[mape,maperat,mapepval] = mapedm(s,sp9m,9,1990,date);

[sr,srpval] = nrbpt(s,sp9m,9,1990,date);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% Trailing geometric average
