% table5nrbf.m

% Ron Alquist

% Bank of Canada

% January 2009


% This program returns the estimates of the non-regression based forecasts: the random walk, futures price,

% spread (without estimated parameters), and Hotelling (if applicable) forecasts in Table 5 of of Alquist and

% Kilian's "What Do We Learn From the Price of Crude Oil Futures?"



clear all;

format short g;

load prices.txt;

load irate.txt;

% Variable names

date = prices(:,1:2);

s = prices(:,3);

f12m = prices(:,8);

sp12m = s.*(1 + log(f12m./s));

i12m = irate(:,5);

sfi12m = s.*(1 + i12m/100);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('12-month RW forecast');

rwmat = [date(13:end,:), s(13:end,1)-s(1:end-12,1)];

b = find(rwmat(:,1)==1991 & rwmat(:,2)==1);

e = find(rwmat(:,1)==2007 & rwmat(:,2)==2);

rwmat1 = rwmat(b:e,:);

rwmspe = mean(rwmat1(:,3).^2);

rwbias = mean(rwmat1(:,3));

rwmape = mean(abs(rwmat1(:,3)));

disp('MSPE:');

disp(rwmspe);

disp('Bias:');

disp(rwbias);

disp('MAPE:');

disp(rwmape);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('12-month futures forecast');

[mspe,msperat,mspepval,bias] = mspedm(s,f12m,12,1990,date);

[mape,maperat,mapepval] = mapedm(s,f12m,12,1990,date);

[sr,srpval] = nrbpt(s,f12m,12,1990,date);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('12-month spread forecast (without estimated parameters)');

[mspe,msperat,mspepval,bias] = mspedm(s,sp12m,12,1990,date);

[mape,maperat,mapepval] = mapedm(s,sp12m,12,1990,date);

[sr,srpval] = nrbpt(s,sp12m,12,1990,date);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('12-month Hotelling forecast');

[mspe,msperat,mspepval,bias] = mspedm(s,sfi12m,12,1990,date);

[mape,maperat,mapepval] = mapedm(s,sfi12m,12,1990,date);

[sr,srpval] = nrbpt(s,sfi12m,12,1990,date);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

