% table5sprd.m

% Ron Alquist

% Bank of Canada

% January 2009


% This program returns the estimates from the spread-based forecasts in Table 5 of 

% Alquist and Kilian's "What Do We Learn From the Price of Crude Oil Futures?"



clear all;

format short g;

load prices.txt;

date = prices(:,1:2);

s = prices(:,3);

f12m = prices(:,8);

ds12m = log(s(13:end,1)./s(1:end-12,1));

lsprd12m = log(f12m(1:end-12,1)./s(1:end-12,1));

sprdmat = [date(13:end,:), ds12m, lsprd12m, s(13:end,1) f12m(13:end,1)];

b = find(sprdmat(:,1)==1990 & sprdmat(:,2)==1);

e = find(sprdmat(:,1)==2007 & sprdmat(:,2)==2);

sprdmat1 = sprdmat(b:e,:);

% Define variables

y = sprdmat1(:,3);

y1 = sprdmat1(:,3) - sprdmat1(:,4);

spot = sprdmat1(:,5);

f = sprdmat1(:,6);

X = [ones(rows(sprdmat1),1) sprdmat1(:,4)];

X1 = [sprdmat1(:,4)];

X2 = [ones(rows(sprdmat1),1)];

lsprd1m1 = sprdmat1(:,4);

B = 999;

h = 12;

d = sprdmat1(:,1:2);

d1 = sprdmat(61:end-10,1:2);

R = 24;

R1 = 36;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('12-month spread forecast: Estimate alpha and beta');

[mspe,msperat,dmmspein,bias,mape,maperat,dmmapein,sr,srpval] = recursivefcast(y,X,R,h,d,spot);

[mspepval, mapepval] = bstrap(d1,prices(73:end-10,3),prices(73:end-10,8),dmmspein,dmmapein,h,R1,1,B);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('12-month spread forecast: Estimate beta only');

[mspe,msperat,dmmspein,bias,mape,maperat,dmmapein,sr,srpval] = recursivefcast(y,X1,R,h,d,spot);

[mspepval, mapepval] = bstrap(d1,prices(73:end-10,3),prices(73:end-10,8),dmmspein,dmmapein,h,R1,2,B);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('12-month spread forecast: Assume beta = 1 and estimate alpha');

[mspe,msperat,dmmspein,bias,mape,maperat,dmmapein,sr,srpval] = recursivefcastb1(y1,sprdmat1(:,4),X2,R,h,d,spot);

[mspepval, mapepval] = bstrap(d1,prices(73:end-10,3),prices(73:end-10,8),dmmspein,dmmapein,h,R1,4,B);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('12-month spread forecast: Estimate alpha only');

[mspe,msperat,dmmspein,bias,mape,maperat,dmmapein,sr,srpval] = recursivefcast(y,X2,R,h,d,spot);

[mspepval, mapepval] = bstrap(d1,prices(73:end-10,3),prices(73:end-10,8),dmmspein,dmmapein,h,R1,3,B);

disp('MSPE ratio:');

disp(msperat);

disp('MSPE p-value:');

disp(mspepval);

disp('Bias:');

disp(bias);

disp('MAPE ratio:');

disp(maperat);

disp('MAPE p-value:');

disp(mapepval);

disp('Success ratio:');

disp(sr);

disp('SR p-value:');

disp(srpval);