% table6.m

% Ron Alquist

% Bank of Canada

% January 2009


% This program returns the entries in Table 6 of Alquist and Kilian's "What Do We Learn From the Price of

% Crude Oil Futures?"

clear all;

format short g;

load prices.txt;

date = prices(:,1:2);

s = prices(:,3);

f3m = prices(:,5);

f6m = prices(:,6);

f12m = prices(:,8);

% 3-month regression

ds3m = log(s(4:rows(s),1)./s(1:rows(s)-3,1));

mat3m = [date(4:rows(date),:) ds3m log(f3m(1:rows(f3m)-3,1)./s(1:rows(s)-3,1))];

b=find(mat3m(:,1)==1989 & mat3m(:,2)==4);

e=find(mat3m(:,1)==2007 & mat3m(:,2)==2);

mat3m1 = mat3m(b:e,:);

y = mat3m1(:,3);

X = [ones(rows(mat3m1),1) mat3m1(:,4)];

[bhat,bhatstd,tbhat,yhat,ehat] = ols(y,X);

t = rows(y);

nlag = round(4*((t/100)^(2/9)));

[V] = nwvcmat(y,X,nlag);

[rbstderr] = nwesterr(y,X,nlag);

alphatstat = bhat(1,:)/rbstderr(1,:);

betatstat = (bhat(2,:)-1)/rbstderr(2,:);

alphapval = 1 - normcdf(abs(alphatstat));

betapval = 1 - normcdf(abs(betatstat));

R = [1 0; 0 1];

r = [0; 1];

wstat = (R*bhat-r)'*inv(R*V*R')*(R*bhat-r);

waldpval = 1 - chi2cdf(wstat,rows(R));

disp('3-month spread regression');

disp('The point estimate of alpha is:');

disp(bhat(1,:));

disp('The p-value for the test that alpha = 0 is:');

disp(alphapval);

disp('The point estimate of beta is:');

disp(bhat(2,:));

disp('The p-value for the test that beta = 1 is:');

disp(betapval);

disp('The p-value for the Wald test that alpha = 0 and beta = 1 is:');

disp(waldpval);

% 6-month regression

ds6m = log(s(7:rows(s),1)./s(1:rows(s)-6,1));

mat6m = [date(7:rows(date),:) ds6m log(f6m(1:rows(f6m)-6,1)./s(1:rows(s)-6,1))];

b=find(mat6m(:,1)==1989 & mat6m(:,2)==4);

e=find(mat6m(:,1)==2007 & mat6m(:,2)==2);

mat6m1 = mat6m(b:e,:);

y = mat6m1(:,3);

X = [ones(rows(mat6m1),1) mat6m1(:,4)];

[bhat,bhatstd,tbhat,yhat,ehat] = ols(y,X);

t = rows(y);

nlag = round(4*((t/100)^(2/9)));

[V] = nwvcmat(y,X,nlag);

[rbstderr] = nwesterr(y,X,nlag);

alphatstat = bhat(1,:)/rbstderr(1,:);

betatstat = (bhat(2,:)-1)/rbstderr(2,:);

alphapval = 1 - normcdf(abs(alphatstat));

betapval = 1 - normcdf(abs(betatstat));

R = [1 0; 0 1];

r = [0; 1];

wstat = (R*bhat-r)'*inv(R*V*R')*(R*bhat-r);

waldpval = 1 - chi2cdf(wstat,rows(R));

disp('6-month spread regression');

disp('The point estimate of alpha is:');

disp(bhat(1,:));

disp('The p-value for the test that alpha = 0 is:');

disp(alphapval);

disp('The point estimate of beta is:');

disp(bhat(2,:));

disp('The p-value for the test that beta = 1 is:');

disp(betapval);

disp('The p-value for the Wald test that alpha = 0 and beta = 1 is:');

disp(waldpval);

% 12-month regression

ds12m = log(s(13:rows(s),1)./s(1:rows(s)-12,1));

mat12m = [date(13:rows(date),:) ds12m log(f12m(1:rows(f12m)-12,1)./s(1:rows(s)-12,1))];

b=find(mat12m(:,1)==1990 & mat12m(:,2)==1);

e=find(mat12m(:,1)==2007 & mat12m(:,2)==2);

mat12m1 = mat12m(b:e,:);

y = mat12m1(:,3);

X = [ones(rows(mat12m1),1) mat12m1(:,4)];

[bhat,bhatstd,tbhat,yhat,ehat] = ols(y,X);

t = rows(y);

nlag = round(4*((t/100)^(2/9)));

[V] = nwvcmat(y,X,nlag);

[rbstderr] = nwesterr(y,X,nlag);

alphatstat = bhat(1,:)/rbstderr(1,:);

betatstat = (bhat(2,:)-1)/rbstderr(2,:);

alphapval = 1 - normcdf(abs(alphatstat));

betapval = 1 - normcdf(abs(betatstat));

R = [1 0; 0 1];

r = [0; 1];

wstat = (R*bhat-r)'*inv(R*V*R')*(R*bhat-r);

waldpval = 1 - chi2cdf(wstat,rows(R));

disp('12-month spread regression');

disp('The point estimate of alpha is:');

disp(bhat(1,:));

disp('The p-value for the test that alpha = 0 is:');

disp(alphapval);

disp('The point estimate of beta is:');

disp(bhat(2,:));

disp('The p-value for the test that beta = 1 is:');

disp(betapval);

disp('The p-value for the Wald test that alpha = 0 and beta = 1 is:');

disp(waldpval);