% table7.m

% Ron Alquist

% Bank of Canada

% January 2009


% This program returns the entries in Table 7 of Alquist and Kilian's "What Do We Learn From the Price of

% Crude Oil Futures?"

clear all;

format short g;

load prices.txt;

date = prices(:,1:2);

s = prices(:,3);

f3m = prices(:,5);

f12m = prices(:,8);

sprd3m = 100*(f3m - s)./s;

sprd12m = 100*(f12m - s)./s;

% Time series features of 3-month spread

mat3m = [date sprd3m];

b=find(mat3m(:,1)==1983 & mat3m(:,2)==4);

e=find(mat3m(:,1)==2007 & mat3m(:,2)==2);

mat3m1 = mat3m(b:e,:);

m3m = mean(mat3m1(:,3));

lag3m = round(4*((rows(mat3m1)/100)^(2/9)));

[tstat3m] = nwest(mat3m1(:,3),ones(rows(mat3m1),1),lag3m);

pval3m = 1 - normcdf(abs(tstat3m));

mad3m = mean(abs(mat3m1(:,3)));

max3m = max(mat3m1(:,3));

min3m = min(mat3m1(:,3));

[p3m] = pfind(mat3m1(:,3),24);

[A3m,SIGMA,U,V] = olsvarc(mat3m1(:,3),p3m);

rho3m = sum(A3m(1,:));

disp('Time-series features of the 3-month spread');

disp('The mean is:');

disp(m3m);

disp('The p-value for the test that the mean = 0 is:');

disp(pval3m);

disp('The mean absolute deviation is:');

disp(mad3m);

disp('The maximum value of the spread is:');

disp(max3m);

disp('The minimum value of the spread is:');

disp(min3m);

disp('The persistence of the spread is:');

disp(rho3m);

% Time series features of 12-month spread

mat12m = [date sprd12m];

b=find(mat12m(:,1)==1989 & mat12m(:,2)==1);

e=find(mat12m(:,1)==2007 & mat12m(:,2)==2);

mat12m1 = mat12m(b:e,:);

m12m = mean(mat12m1(:,3));

lag12m = round(4*((rows(mat12m1)/100)^(2/9)));

[tstat12m] = nwest(mat12m1(:,3),ones(rows(mat12m1),1),lag12m);

pval12m = 1 - normcdf(abs(tstat12m));

mad12m = mean(abs(mat12m1(:,3)));

max12m = max(mat12m1(:,3));

min12m = min(mat12m1(:,3));

[p12m] = pfind(mat12m1(:,3),24);

[A12m,SIGMA,U,V] = olsvarc(mat12m1(:,3),p12m);

rho12m = sum(A12m(1,:));

disp('Time-series features of the 12-month spread');

disp('The mean is:');

disp(m12m);

disp('The p-value for the test that the mean = 0 is:');

disp(pval12m);

disp('The mean absolute deviation is:');

disp(mad12m);

disp('The maximum value of the spread is:');

disp(max12m);

disp('The minimum value of the spread is:');

disp(min12m);

disp('The persistence of the spread is:');

disp(rho12m);